<?php
// $Id: node_invite.rsvp.inc,v 1.2.2.7 2010/03/24 15:55:17 hadsie Exp $
/**
 * @file
 * Provides the invite rsvp response form.
 */

function node_invite_rsvp($form_state, $node, $invite) {
  // this form is probably being accessed by anonymous users.
  $form = array();
      
  if ($node->nid != $invite->nid) {
    drupal_set_message(t("This URL is invalid (iid/nid mismatch)"), 'error');
    return;
  }

  node_invite_specific_info($invite, $node);

  $form['intro'] = array(
    '#value' => token_replace(
      variable_get('node_invite_rsvp_page_intro', NODE_INVITE_RSVP_PAGE_INTRO),
      'node',
      $node
    ),
    '#weight' => 0,
  );

  if (variable_get('node_invite_rsvp_email', 0)) {
    $form['email'] = array(
      '#type' => 'textfield',
      '#title' => t('Your Email'),
      '#description' => t('Please enter the email address to which the original invite was sent. This allows us to make sure you are the actual recipient of the invite.'),
      '#required' => TRUE,
      '#weight' => 1,
    );
  }
  if (variable_get('node_invite_rsvp_show_comments', 0)) {
    $form['comments'] = array(
      '#type' => 'textarea',
      '#title' => t('Comments'),
      '#description' => t('Use this field if you wish to leave a note for the person who invited you.'),
      '#default_value' => $invite->notes_invitee,
      '#weight' => 1,
    );
  }

  $form['attend'] = array(
    '#weight' => 3,
  );
  $form['attend']['pretext'] = array(
    '#value' => token_replace(
      variable_get('node_invite_rsvp_page_submit_pretext', NODE_INVITE_RSVP_PAGE_SUBMIT_PRETEXT),
      'node',
      $node
    ),
    '#prefix' => '<p>',
    '#suffix' => '</p>',
  );

  // @TODO: The response words should be configurable settings.
  // i.e. "attending" instead of "yes"
  $form['attend']['status'] = array(
    '#type' => 'radios',
    '#options' => array(
      NODE_INVITE_RESPONSE_YES => t(NODE_INVITE_RESPONSE_YES),
      NODE_INVITE_RESPONSE_NO => t(NODE_INVITE_RESPONSE_NO),
      NODE_INVITE_RESPONSE_MAYBE => t(NODE_INVITE_RESPONSE_MAYBE),
    ),
    '#default_value' => $invite->status == 'NEW' ? NODE_INVITE_RESPONSE_YES : $invite->status,
    '#attributes' => array('class' => 'radios-inline'),
  );

  if ($invite->uid_invitee) {
    // We should only run into this error with users who are logged in.
    $user = user_load($invite->uid_invitee);
    $form['current_user'] = array(
      '#value' => t('You are RSVPing as %current_user. If this is not you, please <a href="!logout">click here.</a>', array('%current_user' => theme('username', $user), '!logout' => url('logout'))),
      '#prefix' => '<p>',
      '#suffix' => '</p>',
      '#weight' => 19,
    );
  }
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Reply'),
    '#weight' => 20,
  );
  
  // hidden vars for tracking
  $form['node'] = array(
    '#type' => 'value',
    '#value' => $node,
  );
  $form['invite'] = array(
    '#type' => 'value',
    '#value' => $invite,
  );
  
  $form['#redirect'] = 'node/' . $node->nid;
  return $form;
}

function node_invite_rsvp_validate($form, &$form_state) {
  if (intval(variable_get('node_invite_rsvp_email', '0'))) {
    $email = $form_state['values']['email'];
    if (!valid_email_address($email)) {
      // email is not valid.... regardless of whether or not it matches.
      // send them back.
      form_set_error('email', t("$email is not a valid email. Please try again."));
    }
    else {
      $invite = $form_state['values']['invite'];
      if ($email != $invite->email_invitee) {
        form_set_error('email', t("$email is not the address to which this invite was sent.  Please use the <i>exact</i> email to which this invite was sent."));
      }
    }
  }
}

function node_invite_rsvp_submit($form, &$form_state) {
  $invite = $form_state['values']['invite'];

  // Need to double check the status to be translation safe.
  $status = $form_state['values']['status'];
  node_invite_save($invite, array('status' => $status, 'notes_invitee' => $form_state['values']['comments']));

  $node = $form_state['values']['node'];
  $admin_notify_setting = variable_get('node_invite_nots_admin', 'site_admin_all');
  if ($admin_notify_setting == 'site_admin_all') {
    /*
    $from = $to = $GLOBALS['conf']['site_mail'];
    $subject = token_replace(
      variable_get('node_invite_notify_site_admin_all_subject',NODE_INVITE_NOTIFY_SITE_ADMIN_ALL_SUBJECT),
      'node',
      $node
    );
    $the_message = token_replace(
      variable_get('node_invite_notify_site_admin_all',NODE_INVITE_NOTIFY_SITE_ADMIN_ALL),
      'node',
      $node
    );
    $msg = drupal_mail(
      // module
      'node_invite',
      // key
      'rsvp_site_admin_all',
      // to
      $to,
      // language
      language_default(),
      // params
      array(
        'subject' => $subject,
        'body'    => $the_message,
      ),
      // from
      $from,
      // send
      TRUE
    );
    */
  }
  elseif ($admin_notify_setting == 'site_admin_yes' && $form_state['values']['op'] == t(NODE_INVITE_RESPONSE_YES)) {
    /*
    $the_message = token_replace(
      variable_get('node_invite_notify_site_admin_yes',NODE_INVITE_NOTIFY_SITE_ADMIN_YES),
      'node',
      $node
    );
    $subject = token_replace(
      variable_get('node_invite_notify_site_admin_yes_subject',NODE_INVITE_NOTIFY_SITE_ADMIN_YES_SUBJECT),
      'node',
      $node
    );
    $from = $to = $GLOBALS['conf']['site_mail'];
    $msg = drupal_mail(
      // module
      'node_invite',
      // key
      'rsvp_site_admin_yes',
      // to
      $to,
      // language
      language_default(),
      // params
      array(
        'subject' => $subject,
        'body'    => $the_message,
      ),
      // from
      $from,
      // send
      TRUE
    );
    */
  }

  // notify the inviter
  $notify_settings = variable_get('node_invite_nots_rsvps', array('inviter', 'invitee'));
  if (in_array('inviter', $notify_settings)) {
    $the_message = token_replace(
      variable_get('node_invite_notify_inviter_notify', NODE_INVITE_NOTIFY_INVITER_NOTIFY),
      'node',
      $node
    );
    $from = $GLOBALS['conf']['site_mail'];
    $to = db_result(db_query("SELECT u.mail FROM {users} u JOIN {node_invites} ni ON u.uid = ni.uid_inviter WHERE iid = %d", $invite->iid));
    $subject = token_replace(
      variable_get('node_invite_notify_inviter_notify_subject', NODE_INVITE_NOTIFY_INVITER_NOTIFY_SUBJECT),
      'node',
      $node
    );
    $msg = drupal_mail(
      // module
      'node_invite',
      // key
      'rsvp_inviter',
      // to
      $to,
      // language
      language_default(),
      // params
      array(
        'subject' => $subject,
        'body'    => $the_message,
      ),
      // from
      $from,
      // send
      TRUE
    );
  }

  // To allow for redirection
  unset($form_state['storage']);
}
